/*
 *  Authors:  huanfuxi <huanfuxi@kylinos.cn>
 *  Authors:  liuyi <liuyi@kylinos.cn>
 *
 *  Copyright (c) KylinSoft Co., Ltd [2024].All rights reserved.
 */
#ifndef KYSEC_LOG_H
#define KYSEC_LOG_H

enum kysec_log_type {
	KYSECLOG_LIB_KYSEC = 0,		/* libkysec */
	KYSECLOG_LIB_EXTEND,		/* libkysec_extend */
	KYSECLOG_LIB_KYSECWHLIST,	/* libkysecwhlist */
	KYSECLOG_LIB_CORE,		/* libkysec_core */
	KYSECLOG_LIB_ADV,		/* libkysec_adv */
	KYSECLOG_CMD_SETSTATUS = 5,	/* setstatus */
	KYSECLOG_CMD_GETSTATUS,		/* getstatus */
	KYSECLOG_CMD_KYSEC,		/* kysec */
	KYSECLOG_CMD_SYNC,		/* kysec-sync */
	KYSECLOG_CMD_SYNC_DAEMON,	/* kysec-sync-daemon */
	KYSECLOG_CMD_DAEMON,		/* kysec-daemon */
	KYSECLOG_CMD_AUTH,		/* kysec_auth */
	KYSECLOG_CMD_KMOD = 12,		/* kysec_kmod */
	KYSECLOG_CMD_KSC_DEFENDER = 13,	/* ksc_defender	*/
	KYSECLOG_CMD_KSC_DEFENDER_DAEMON = 14,	/* ksc_defender_daemon	*/
	KYSECLOG_LOG,
	KYSECLOG_LIB_LOG,
	KYSECLOG_CMD_POLICY,	/*kysec_policy*/
	/* for kysec2 scene */
	KYSECLOG_KYSEC2_SCENE,
	KYSECLOG_MAX			/* kysec log max type, limited value */
};

enum kysec_log_level_type {
	KYSECLOG_FATAL,
	KYSECLOG_ERROR,
	KYSECLOG_WARNING,
	KYSECLOG_INFO,
	KYSECLOG_DEBUG,
	KYSECLOG_TRACE,
	KYSECLOG_LEVEL_MAX,
};

#ifdef __cplusplus
extern "C" {
#endif

/* kysec日志记录接口
 * @type: 取值kysec_log_type枚举
 * @op: 指添加、删除、更新白名单等具体操作，该字符串长度不能超过100
 * @obj: 指当前的操作对象，该字符串长度不能超过PATH_MAX
 * @format: 指具体的失败信息，或想要记录的任何信息均可，该字符串长度不能超过1024
 */
void kysec_log(int type, char *op, char *obj, char *format, ...);

/**
 * @brief kysec v2版本日志记录接口 (新增 日志等级)
 * @param level 日志等级  见 ksyec_log_level_type枚举类型
 * @param type 见 kysec_log_type
 * @param op 指添加、删除、更新白名单等具体操作，该字符串长度不能超过100
 * @param obj 指当前的操作对象，该字符串长度不能超过PATH_MAX
 * @param format 指具体的失败信息，或想要记录的任何信息均可，该字符串长度不能超过1024
 *
*/
void kysec_log_v2(int level, int type, const char *op, const char *obj, const char* format, ...);

#ifdef __cplusplus
}
#endif

#endif /* KYSEC_LOG_H */
